@@ -22,6 +22,7 @@
 #  include <config.h>
 #endif
 
+#include <stdlib.h>
 #include <glade/glade.h>
 #include <glib/gi18n.h>
 
@@ -35,7 +36,6 @@ GstTool *tool;
 static GstDialogSignal signals[] = {
   /* connections tab */
   { "properties_button",            "clicked", G_CALLBACK (on_iface_properties_clicked) },
-  { "gateways_combo",               "changed", G_CALLBACK (on_gateway_combo_changed) },
   /* general tab */
   { "domain",                       "focus-out-event", G_CALLBACK (on_domain_focus_out) },
   { "hostname",                     "changed", G_CALLBACK (on_entry_changed) },
@@ -47,11 +47,11 @@ static GstDialogSignal signals[] = {
   /* host aliases dialog */
   { "host_alias_address",           "changed", G_CALLBACK (on_host_aliases_dialog_changed) },
   /* connection dialog */
-  { "connection_config_dialog",     "delete-event", G_CALLBACK (on_connection_dialog_close) },
+  { "connection_config_dialog",     "response", G_CALLBACK (on_connection_response) },
+  { "connection_config_dialog",     "delete-event", G_CALLBACK (gtk_true) },
   { "connection_device_active",     "clicked", G_CALLBACK (on_iface_active_changed) },
+  { "connection_device_roaming",    "clicked", G_CALLBACK (on_iface_roaming_changed) },
   { "connection_bootproto",         "changed", G_CALLBACK (on_bootproto_changed) },
-  { "connection_cancel",            "clicked", G_CALLBACK (on_connection_cancel_clicked) },
-  { "connection_ok",                "clicked", G_CALLBACK (on_connection_ok_clicked) },
   { "connection_detect_modem",      "clicked", G_CALLBACK (on_detect_modem_clicked) },
   /* dialog changing detection */
   { "connection_address",           "focus-out-event", G_CALLBACK (on_ip_address_focus_out) },
@@ -162,6 +162,7 @@ main (int argc, gchar *argv[])
     { NULL }
   };
 
+  g_thread_init (NULL);
   gst_init_tool ("network-admin", argc, argv, entries);
   tool = gst_network_tool_new ();
 
