@@ -46,12 +46,14 @@ void on_manage_groups_clicked (GtkWidget *widget, gpointer user_data);
 void on_group_new_clicked (GtkButton*, gpointer);
 void on_group_settings_clicked (GtkButton*, gpointer);
 void on_group_delete_clicked (GtkButton*, gpointer);
+void on_groups_dialog_show_help (GtkWidget *widget, gpointer data);
 
 /* user settings dialog callbacks */
 void on_user_settings_passwd_changed (GtkEntry*, gpointer);
 void on_user_settings_passwd_random_new (GtkButton*, gpointer);
 void on_user_settings_passwd_toggled (GtkToggleButton*, gpointer);
 void on_user_settings_login_changed (GtkEditable *editable, gpointer data);
+void on_user_settings_profile_changed (GtkWidget *widget, gpointer data);
 
 
 #endif /* CALLBACKS_H */
