@@ -24,31 +24,19 @@
 #ifndef __TABLE_H
 #define __TABLE_H
 
-#include <gnome.h>
-
-#include "user_group.h"
-#include "callbacks.h"
-
-#define COLOR_NORMAL "black"
+#include "gst.h"
+#include "users-tool.h"
 
 enum {
-	POPUP_NONE,
-	POPUP_ADD,
-	POPUP_SEPARATOR,
-	POPUP_SETTINGS,
-	POPUP_DELETE
+	TABLE_USERS,
+	TABLE_GROUPS,
 };
 
-/* User and group lists creation function */
-void                    create_gtk_tree_list		(GtkWidget*, GtkTargetEntry);
-void			populate_gtk_tree_list		(GtkTreeView*, GList*);
-GList*                  get_gtk_tree_list_items         (GtkTreeView*);
-GtkItemFactory *        popup_item_factory_create       (GtkWidget *widget);
+GtkWidget*  popup_menu_create          (GtkWidget *wigdet, gint table);
+void	    create_tables	       (GstUsersTool *tool);
+GList*      table_get_row_references   (gint table, GtkTreeModel **model);
+void        table_populate_profiles    (GstUsersTool *tool, GList *names);
+void        table_set_default_profile  (GstUsersTool *tool);
 
-/* User and group tables manipulation functions */
-void			create_tables			(void);
-void			update_tables_complexity	(GstDialogComplexity);
-void			populate_all_tables		(void);
-xmlNodePtr		get_selected_row_node		(gint);
 
 #endif /* __TABLE_H */
